@@ -357,9 +357,9 @@ class ASFProduct:
 
         return self.umm_cast(mapping['cast'], value)
 
-    def translate_product(self, item: Dict) -> Dict:
-        """
-        Generates `properties` and `geometry` from the CMR UMM response
+    def _get_geometry(self, item: Dict):
+        """Helper method that creates a geometry context dictionary. 
+        Meant primarily for NISARProduct to override for dateline multipolygon parsing.
         """
         try:
             coordinates = item['umm']['SpatialExtent']['HorizontalSpatialDomain']['Geometry'][
@@ -370,6 +370,13 @@ class ASFProduct:
         except KeyError:
             geometry = {'coordinates': None, 'type': 'Polygon'}
 
+        return geometry
+    
+    def translate_product(self, item: Dict) -> Dict:
+        """
+        Generates `properties` and `geometry` from the CMR UMM response
+        """
+        geometry = self._get_geometry(item)
         umm = item.get('umm')
 
         # additionalAttributes = {attr['Name']: attr['Values'] for attr in umm['AdditionalAttributes']}
